!
! This file contains the contents of the file SatForms.mda in
! text format.  It is intended as reference for users that do
! not have Microsoft Access and thus cannot open the SatForms.mda
! file. The information contained in the comments in this file is
! equally applicable to any DBMS that supports ActiveX
! (aka custom controls or OLE controls).
!

!Option Compare Database
!Option Explicit

!***************************************************************************
! 
! Status codes and parameters of HotSyncStatus event
!
! The HotSyncStatus event contains 2 parameters:
!
!     StatusCode:  This code specifies the HotSync event that has occurred.
!
!     Param:       A generic parameter that has different meaning depending
!                  on StatusCode above (see description of status codes for
!                  more details).
!
!     Related Properties:
!
!         PilotUserName:    Contains the HotSync Manager user name of the
!                           PalmPilot being HotSync!d.
!
!         UserID:           The Satellite Forms unique user ID that identifies
!                           this PalmPilot.  (This is NOT the same as the
!                           HotSyncUserId used by the Hs* methods below.)
!
!         CmdType:          (This property is only valid when StatusCode =
!                           StatusHotSyncCommandComplete.)  The type of
!                           command that just completed. (see CmdType_*
!                           constants below.)
!
!         CmdFilename:      (This property is only valid when StatusCode =
!                           StatusHotSyncCommandComplete.)  Contains the
!                           filename (if any) associated with the command
!                           that just completed.
!
!***************************************************************************

! StatusCode: Status_HotSyncStart
!
! The user has pressed the HotSync button on the PalmPilot cradle
! and the Satellite Forms conduit is ready to accept commands.
! During this event, determine what needs to be done (possibly
! based on the user name or user ID on the PalmPilot) and issue any file
! transfer commands you require.

Status_HotSyncStart             EQUATE(1)

!-----------------------------------------------------------------------------
   
! StatusCode: Status_HotSyncCommandComplete
!
! Each file transfer operation you request will generate this event when
! it completes. If the command was successful, Param will be "1". Otherwise
! it will be "0".

Status_HotSyncCommandComplete   EQUATE(3)

! command codes in property CmdType of the Satellite Forms ActiveX control
! during Status_HotSyncCommandComplete notifications
   
CmdType_Unknown                 EQUATE(0)
CmdType_CopyAppToPda            EQUATE(1)
CmdType_Reserved0               EQUATE(2)
CmdType_CopyTableToPda          EQUATE(3)
CmdType_GetTableFromPda         EQUATE(4)
CmdType_Reserved1               EQUATE(5)
CmdType_ReadPdaInfo             EQUATE(6)
CmdType_CopyAppToPdaEx          EQUATE(7)
CmdType_CopyTableToPdaEx        EQUATE(8)
CmdType_CopyPrcToPda            EQUATE(9)

!-----------------------------------------------------------------------------
   
! StatusCode: Status_HotSyncEnd
!
! The Satellite Forms HotSync session is completed. The cumulative result of all
! HotSync operations is passed in Param.  If all operations were successful,
! Param will be "1". If any or all commands failed, Param will be "0".

Status_HotSyncEnd               EQUATE(2)

!*****************************************************************************
!*
!* Methods supported by the Satellite forms control
!*
!*****************************************************************************

!-----------------------------------------------------------------------------
! ********************** Conduit Operation Methods ***************************
!-----------------------------------------------------------------------------
   
! *** CopyTableToPalmPilot(Filename As String) ***
!
! Calling this method causes the dBase table specified by Filename to be copied
! to the PalmPilot.  The dBase file required by this method is a .DBF file
! saved by App Designer (specify full path).
!
! Note: This method only causes a request that the table be copied to be
! queued with the conduit.  On completion of this method, the operation has NOT
! occurred yet.  The operation will only take place when the conduit gets control
! again (usually when you exit your HotSyncStatus event handler). A HotSyncStatus
! event with StatusCode = Status_HotSyncCommandComplete will be fired after the
! transfer operation actually occurs.
! szProperty = 'CopyTableToPalmPilot(''' & FilePath & ''')'''
! ?SatForms(szProperty)
!CASE szMyFileToExport
!  OF 'XXX'
!     ?SatForms{'CopyTableToPalmPilot(''c:\ssdf\XXX'')'}
!  OF ...
!
!END
!-----------------------------------------------------------------------------
   
! *** CopyTableToPalmPilotEx(Filename As String, CreatorID As Integer) ***
!
! Calling this method causes the dBase table specified by Filename to be copied
! to the PalmPilot as in CopyTableToPalmPilot() above. The difference is that the
! table is copied to the PalmPilot with the creator ID specified in the parameter
! CreatorID. (This feature is usually only used with the RTK to group files by
! creator -- see your manual for more information.)
!
! Note: This method only causes a request that the table be copied to be
! queued with the conduit.  On completion of this method, the operation has NOT
! occurred yet.  The operation will only take place when the conduit gets control
! again (usually when you exit your HotSyncStatus event handler). A HotSyncStatus
! event with StatusCode = Status_HotSyncCommandComplete will be fired after the
! transfer operation actually occurs.

!-----------------------------------------------------------------------------

! *** GetTableFromPalmPilot(Filename As String) ***
!
! Calling this method causes the dBase table specified by Filename to be
! retrieved from the PalmPilot.  The dBase file required by this method is a
! .DBF file saved by App Designer (specify full path).
!
! Note: This method only causes a request that the table be retrieved to be
! queued with the conduit.  On completion of this method, the operation has NOT
! occurred yet.  The operation will only take place when the conduit gets control
! again (usually when you exit your HotSyncStatus event handler). A HotSyncStatus
! event with StatusCode = Status_HotSyncCommandComplete will be fired after the
! transfer operation actually occurs.

!-----------------------------------------------------------------------------

! *** CopyAppToPalmPilot(Filename As String) ***
!
! Calling this method causes the application specified by Filename to be copied
! to the PalmPilot.  The application file required by this method is the .PDA file
! saved by App Designer (specify full path).  This method only copies the application
! to the PalmPilot. Make sure to copy the tables required by the application also.
! If you are using this method to upgrade an application on the PalmPilot, make sure
! to copy any new or changed tables (if any) required by the new application to the
! PalmPilot also.
!
! Note: This method only causes a request that the application be copied to be
! queued with the conduit.  On completion of this method, the operation has NOT
! occurred yet.  The operation will only take place when the conduit gets control
! again (usually when you exit your HotSyncStatus event handler). A HotSyncStatus
! event with StatusCode = Status_HotSyncCommandComplete will be fired after the
! transfer operation actually occurs.

!-----------------------------------------------------------------------------

! *** CopyAppToPalmPilotEx(Filename As String, CreatorID as Integer) ***
!
! Calling this method causes the application specified by Filename to be copied
! to the PalmPilot as in CopyAppToPalmPilot above. The difference is that the
! app is copied to the PalmPilot with the creator ID specified in the parameter
! CreatorID. (This feature is usually only used with the RTK to group files by
! creator -- see your manual for more information.)
!
! Note: This method only causes a request that the application be copied to be
! queued with the conduit.  On completion of this method, the operation has NOT
! occurred yet.  The operation will only take place when the conduit gets control
! again (usually when you exit your HotSyncStatus event handler). A HotSyncStatus
! event with StatusCode = Status_HotSyncCommandComplete will be fired after the
! transfer operation actually occurs.

!-----------------------------------------------------------------------------

! *** InstallPrcFileToPalmPilot(Filename As String, HotSyncUserId as Integer)
! ***     As Boolean 
!
! Calling this method causes the PalmPilot native file (.PRC or .PDB extension)
! specified in Filename to be to installed on the PalmPilot specified by
! HotSyncUserId. If you call this method during a HotSync event (e.g. as part
! of handling a HotSyncStatus event), you may specify 0 (zero) as the
! HotSyncUserId to indicate that the PRC file should be installed to the
! PalmPilot currently being HotSync!d.  Otherwise, use the methods in the User
! Management section below to determine the proper HotSyncUserId.
!
! If the function succeeds, it will return True (non-zero), otherwise it will
! return False (zero).
!
! Note: This method only "prepares" the files to be installed.  The files will
! only actually be installed when a HotSync session of the specified PalmPilot
! is performed to completion.  Note that if you call this method from within
! your HotSyncStatus event handler with HotSyncUserId set to zero, the PRC file
! will be installed at the end of the current HotSync session.

!-----------------------------------------------------------------------------
! *********************** User Management Methods ****************************
!
! Note: These methods allow manipulation of the user list kept by the
!       PalmPilot HotSync Manager. IMPORTANT: changes are not actually
!       made to the user list until you call HsCommitUserChanges().  You
!       may discard any changes you!ve made by calling HsAbandonChanges()
!       instead.
!       
!-----------------------------------------------------------------------------

! *** HsCommitChanges() As Boolean
!
! Call this method to save all changes made up to this point.  No changes are
! actually made by any of the Hs* functions until you call this method.
!
! If the function succeeds, it will return True (non-zero). Otherwise, it
! will return False (zero).

!-----------------------------------------------------------------------------

! *** HsAbandonChanges() As Boolean
!
! Call this method to discard any changes made since the last call to
! HsCommitChanges().
!
! If the function succeeds, it will return True (non-zero). Otherwise, it
! will return False (zero).

!-----------------------------------------------------------------------------
   
! *** HsGetFirstUser(HotSyncUserId As Long, HotSyncUserName As String,
! ***     HotSyncSubDir As String, fInstalled As Boolean) As Boolean
!
! Calling this method returns information about the first user in the
! HotSync Manager!s user list.  HotSyncUserId and HotSyncUserName are filled with
! the HotSync Manager!s user ID and name of the first user.  The HotSyncSubDir
! variable is filled with the subdirectory of the HotSync directory that is
! associated with this user.  fInstalled is set to True if the user has been
! installed on a PalmPilot and False if not.
!
! If the function succeeds (i.e. there is at least one user), it will return
! True (non-zero). Otherwise, it will return False (zero).

!-----------------------------------------------------------------------------

! *** HsGetNextUser(HotSyncUserId As Long, HotSyncUserName As String,
! ***     HotSyncSubDir As String, fInstalled As Boolean) As Boolean
!
! Call this method after calling HsGetFirstUser() to return the second and
! subsequent users in the HotSync Manager!s user list. HotSyncUserId and
! HotSyncUserName are filled with the HotSync Manager!s user ID and name
! of the next user.  The HotSyncSubDir variable is filled with the
! subdirectory of the HotSync directory that is associated with this user.
! fInstalled is set to True if the user has been installed on a PalmPilot
! and False if not.
!
! If the function succeeds (i.e. there is another user), it will return
! True (non-zero). Otherwise, it will return False (zero).

!-----------------------------------------------------------------------------

! *** HsFindUserById(HotSyncUserId As Long, HotSyncUserName As String,
! ***     HotSyncSubDir As String, fInstalled As Boolean) As Boolean   
!
! Call this method to retrieve information about a user by HotSync Manager
! User ID.  Fill in HotSyncUserId with the User ID to be searched for and
! call this method.  The HotSyncUserName, HotSyncSubDir and fInstalled are
! filled in as described in HsGetFirstUser().
!
! If the function succeeds (i.e. a user that matches the specified User ID
! exists), it will return True (non-zero). Otherwise, it will return False
! (zero).

!-----------------------------------------------------------------------------

! *** HsAddUser(HotSyncUserName As String, HotSyncUserId As Long,
! ***     HotSyncSubDir As String) As Boolean
!
! Call to create a new user in the HotSync Manager user list. Fill in
! HotSyncUserName with the desired user name and call this method.  A new
! user will be created and HotSyncUserId and HotSyncSubDir will be filled
! in with the HotSync User ID and subdirectory created for the new user.
!
! If the function succeeds, it will return True (non-zero). Otherwise, it
! will return False (zero).

!-----------------------------------------------------------------------------

! *** HsDeleteUser(HotSyncUserId As Long) As Boolean
!
! Call this method to delete a user from the HotSync Manager user list.
! Specify the user to delete by placing its HotSync Manager user ID into
! the parameter HotSyncUserId.
!
! If the function succeeds, it will return True (non-zero). Otherwise, it
! will return False (zero).

!-----------------------------------------------------------------------------

! *** HsRenameUser(HotSyncUserId As Long, NewUserName As String) As Boolean
!
! Call this method to rename a user in the HotSync Manager user list. Specify
! the user to rename by placing its HotSync Manager user ID into the parameter
! HotSyncUserId.  Place the desired new name into the parameter NewUserName.
!
! If the function succeeds, it will return True (non-zero). Otherwise, it
! will return False (zero).
